@@ -7,7 +7,7 @@ RDF::Trine::Node::Literal - RDF Node class for literals
 
 =head1 VERSION
 
-This document describes RDF::Trine::Node::Literal version 0.133
+This document describes RDF::Trine::Node::Literal version 0.134
 
 =cut
 
@@ -27,7 +27,7 @@ use Carp qw(carp croak confess);
 
 our ($VERSION, $USE_XMLLITERALS, $USE_FORMULAE);
 BEGIN {
-	$VERSION	= '0.133';
+	$VERSION	= '0.134';
 	eval "use RDF::Trine::Node::Literal::XML;";
 	$USE_XMLLITERALS	= (RDF::Trine::Node::Literal::XML->can('new')) ? 1 : 0;
 	eval "use RDF::Trine::Node::Formula;";
@@ -138,6 +138,17 @@ sub literal_datatype {
 	return $self->[2];
 }
 
+=item C<< value >>
+
+Returns the literal value.
+
+=cut
+
+sub value {
+	my $self	= shift;
+	return $self->literal_value;
+}
+
 =item C<< sse >>
 
 Returns the SSE string for this literal.
@@ -312,6 +323,9 @@ sub canonicalize_literal_value {
 			if ($num =~ /^[.]/) {
 				$num	= "0$num";
 			}
+			if ($num !~ /[.]/) {
+				$num	= "${num}.0";
+			}
 			return "${sign}${num}";
 		} elsif ($value =~ m/^([-+])?([.]\d+)$/) {
 			my $sign	= $1 || '';
