@@ -7,7 +7,7 @@ RDF::Trine::Node::Resource - RDF Node class for resources
 
 =head1 VERSION
 
-This document describes RDF::Trine::Node::Resource version 0.133
+This document describes RDF::Trine::Node::Resource version 0.134
 
 =cut
 
@@ -28,7 +28,7 @@ use Carp qw(carp croak confess);
 
 our ($VERSION, %sse, %ntriples);
 BEGIN {
-	$VERSION	= '0.133';
+	$VERSION	= '0.134';
 }
 
 ######################################################################
@@ -112,6 +112,17 @@ sub uri_value {
 	return $self->[1];
 }
 
+=item C<< value >>
+
+Returns the URI/IRI value.
+
+=cut
+
+sub value {
+	my $self	= shift;
+	return $self->uri_value;
+}
+
 =item C<< uri ( $uri ) >>
 
 Returns the URI value of this resource, optionally updating the URI.
@@ -249,11 +260,12 @@ QName, returns a list containing these two parts. Otherwise throws an exception.
 sub qname {
 	my $p		= shift;
 	my $uri		= $p->uri_value;
-	
-	my $nameStartChar	= qr<([A-Za-z_]|[\x{C0}-\x{D6}]|[\x{D8}-\x{D8}]|[\x{F8}-\x{F8}]|[\x{200C}-\x{200C}]|[\x{37F}-\x{1FFF}][\x{200C}-\x{200C}]|[\x{2070}-\x{2070}]|[\x{2C00}-\x{2C00}]|[\x{3001}-\x{3001}]|[\x{F900}-\x{F900}]|[\x{FDF0}-\x{FDF0}]|[\x{10000}-\x{10000}])>;
-	my $nameChar		= qr<$nameStartChar|-|[.]|[0-9]|\x{B7}|[\x{0300}-\x{036F}]|[\x{203F}-\x{2040}]>;
-	my $lnre			= qr<((${nameStartChar})($nameChar)*)>;
-	if ($uri =~ m/${lnre}$/) {
+
+	our $r_PN_CHARS_BASE	||= qr/([A-Z]|[a-z]|[\x{00C0}-\x{00D6}]|[\x{00D8}-\x{00F6}]|[\x{00F8}-\x{02FF}]|[\x{0370}-\x{037D}]|[\x{037F}-\x{1FFF}]|[\x{200C}-\x{200D}]|[\x{2070}-\x{218F}]|[\x{2C00}-\x{2FEF}]|[\x{3001}-\x{D7FF}]|[\x{F900}-\x{FDCF}]|[\x{FDF0}-\x{FFFD}]|[\x{10000}-\x{EFFFF}])/;
+	our $r_PN_CHARS_U		||= qr/(_|${r_PN_CHARS_BASE})/;
+	our $r_PN_CHARS			||= qr/${r_PN_CHARS_U}|-|[0-9]|\x{00B7}|[\x{0300}-\x{036F}]|[\x{203F}-\x{2040}]/;
+	our $r_PN_LOCAL			||= qr/((${r_PN_CHARS_U})((${r_PN_CHARS}|[.])*${r_PN_CHARS})?)/;
+	if ($uri =~ m/${r_PN_LOCAL}$/) {
 		my $ln	= $1;
 		my $ns	= substr($uri, 0, length($uri)-length($ln));
 		return ($ns, $ln);
