@@ -7,7 +7,7 @@ RDF::Trine::Node::Variable - RDF Node class for variables
 
 =head1 VERSION
 
-This document describes RDF::Trine::Node::Variable version 0.133
+This document describes RDF::Trine::Node::Variable version 0.134
 
 =cut
 
@@ -26,7 +26,7 @@ use Carp qw(carp croak confess);
 
 our ($VERSION);
 BEGIN {
-	$VERSION	= '0.133';
+	$VERSION	= '0.134';
 }
 
 ######################################################################
@@ -89,6 +89,17 @@ sub as_string {
 	return '?' . $self->name;
 }
 
+=item C<< value >>
+
+Returns the variable name.
+
+=cut
+
+sub value {
+	my $self	= shift;
+	return $self->name;
+}
+
 =item C<< as_ntriples >>
 
 Returns the node in a string form suitable for NTriples serialization.
