@@ -4,7 +4,7 @@ RDF::Trine::Store::DBI - Persistent RDF storage based on DBI
 
 =head1 VERSION
 
-This document describes RDF::Trine::Store::DBI version 0.133
+This document describes RDF::Trine::Store::DBI version 0.134
 
 =head1 SYNOPSIS
 
@@ -47,7 +47,7 @@ use RDF::Trine::Store::DBI::Pg;
 
 our $VERSION;
 BEGIN {
-	$VERSION	= "0.133";
+	$VERSION	= "0.134";
 	my $class	= __PACKAGE__;
 	$RDF::Trine::Store::STORE_CLASSES{ $class }	= $VERSION;
 }
@@ -101,12 +101,8 @@ The password of the database user.
 
 Initialize the store with a L<DBI::db> object.
 
-
 =cut
 
-
-
-
 sub new {
 	my $class	= shift;
 	my $dbh;
@@ -465,9 +461,9 @@ sub add_statement {
 	my $sth	= $dbh->prepare( $sql );
 	$sth->execute( @values );
 	unless ($sth->fetch) {
-		my $sql		= sprintf( "INSERT INTO ${stable} (Subject, Predicate, Object, Context) VALUES (%s,%s,%s,%s)", @values );
+		my $sql		= sprintf( "INSERT INTO ${stable} (Subject, Predicate, Object, Context) VALUES (?,?,?,?)" );
 		my $sth		= $dbh->prepare( $sql );
-		$sth->execute();
+		$sth->execute(@values);
 	}
 }
 
